/**  
  *  RGB16Mio_Creator Version 1.0, 2008-10-10, by 
  *  Martin Schlueter, i3mainz, Mainz University of Applied Sciences, Germany
  *
  *  This ImageJ plugin creates an 8-bit per channel RGB image containing 
  *  exactly one pixel of each of the 16,777,216 possible RGB color values. 
  *  The image is 4096  4096 pixels, arranged as 256 slices of the RGB color 
  *  cube. It is intended to investiga the accuracy of color transforms.
  *  
  *  For consultance and practical applications concerning Mobile 3D Coordinate
  *  Measuring Techniques, 3D Digitizing, Deformation Measurement and Analysis 
  *  please contact
  *  Martin Schlueter: schlueter(at)geoinform.fh-mainz.de   
  *  
  *  Copyright (c) [2008-10-10] by Prof. Dr.-Ing. Martin Schlueter, i3mainz,
  *  Mainz University of Applied Sciences, Germany

  *  Permission is hereby granted, free of charge, to any person obtaining a 
  *  copy of this software and associated documentation files (the "Software"), 
  *  to deal in the Software without restriction, including without limitation 
  *  the rights to use, copy, modify, merge, publish, distribute, sublicense, 
  *  and/or sell copies of the Software, and to permit persons to whom the 
  *  Software is furnished to do so, subject to the following conditions:
  *  The above copyright notice and this permission notice shall be included in
  *  all copies or substantial portions of the Software.
  *
  *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
  *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
  *  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
  *  DEALINGS IN THE SOFTWARE.
  *
  *  OSI Certified Open Source Software
  *
  * History
  * 2008/10/10: First version online
  *
  */

import ij.*;
import ij.process.*;
import ij.plugin.PlugIn;

public class RGB16Mio_Creator implements PlugIn {

    public void run(String arg) {

        int w = 4096, h = 4096;
        ImageProcessor ip = new ColorProcessor(w, h);

        for (int i = 0; i < 16; i++) {
            for (int j = 0; j < 16; j++) {
                for (int v = 0; v < 256; v++) {
                    for (int u = 0; u < 256; u++) {
                        int c = (( u & 0xff)<<16) | (( v & 0xff)<<8) | (i+16*j) & 0xff; 
                        ip.set(i*256+u, j*256+v, c);
                    }
                }
            }   
        }     
        new ImagePlus("RGB16Mio", ip).show();
     }
}

